@@ -8,10 +8,11 @@ def default_cache_func(
 ):
     redis_model = create_redis_model_from_django_model(django_model, redis_root)
     redis_dicts = redis_root.get(redis_model, return_dict=True)
-    cache_to_django(
-        django_model,
-        redis_dicts
-    )
+    print(len(redis_dicts.keys()))
+    # cache_to_django(
+    #     django_model,
+    #     redis_dicts
+    # )
     django_to_cache(
         django_model,
         redis_model,
