@@ -4,8 +4,7 @@ import json
 import redis
 from copy import deepcopy
 from typing import Callable
-from django.db.models import Model as DjangoModel
-from django.db.models import fields as django_fields
+from django.db import models as django_models
 from .utils import check_types, check_classes, get_ids_from_untyped_data
 from .cache import default_cache_func
 
@@ -328,12 +327,12 @@ class RedisDate(RedisString):
 #     def __init__(self, model=None, **kwargs):
 #         super().__init__(**kwargs)
 #         self.model = None
-#         if not issubclass(model.__class__, DjangoModel):
+#         if not issubclass(model.__class__, django_models.Model):
 #             raise Exception(f'{model.__class__.__name__} class is not django.db.models Model')
 #         self.model = model
 #
 #     def _get_id_from_instance(self):
-#         if issubclass(self.value.__class__, DjangoModel):
+#         if issubclass(self.value.__class__, django_models.Model):
 #             if isinstance(self.value, self.model):
 #                 if self.value.id:
 #                     django_instances_with_this_id = self.model.objects.filter(id=self.value.id)
@@ -452,33 +451,33 @@ class RedisRoot:
                     return allowed_redis_params
 
                 field_mapping = {
-                    django_fields.BooleanField: RedisBool,
-                    django_fields.DecimalFeild: RedisDecimal,
-                    django_fields.PostitiveSmallIntegerField: RedisNumber,
-                    django_fields.BigAutoField: RedisNumber,
-                    django_fields.BigIntegerField: RedisNumber,
-                    django_fields.DateField: RedisDate,
-                    django_fields.DateTimeField: RedisDateTime,
-                    django_fields.EmailField: RedisString,
-                    django_fields.IntegerField: RedisNumber,
-                    django_fields.GenericIPAddressField: RedisString,
-                    django_fields.JSONField: RedisJson,
-                    django_fields.PositiveBigIntegerField: RedisNumber,
-                    django_fields.PositiveIntegerField: RedisNumber,
-                    django_fields.PositiveSmallIntegerField: RedisNumber,
-                    django_fields.SmallAutoField: RedisNumber,
-                    django_fields.SmallIntegerField: RedisNumber,
-                    django_fields.TextField: RedisString,
-                    django_fields.URLField: RedisString,
-                    django_fields.UUIDField: RedisString,
-                    django_fields.ForeignKey: RedisForeignKey,
-                    django_fields.ManyToManyField: RedisManyToMany
+                    django_models.BooleanField: RedisBool,
+                    django_models.DecimalField: RedisDecimal,
+                    django_models.PositiveSmallIntegerField: RedisNumber,
+                    django_models.BigAutoField: RedisNumber,
+                    django_models.BigIntegerField: RedisNumber,
+                    django_models.DateField: RedisDate,
+                    django_models.DateTimeField: RedisDateTime,
+                    django_models.EmailField: RedisString,
+                    django_models.IntegerField: RedisNumber,
+                    django_models.GenericIPAddressField: RedisString,
+                    django_models.JSONField: RedisJson,
+                    django_models.PositiveBigIntegerField: RedisNumber,
+                    django_models.PositiveIntegerField: RedisNumber,
+                    django_models.SmallAutoField: RedisNumber,
+                    django_models.SmallIntegerField: RedisNumber,
+                    django_models.TextField: RedisString,
+                    django_models.URLField: RedisString,
+                    django_models.UUIDField: RedisString,
+                    django_models.ForeignKey: RedisForeignKey,
+                    django_models.ManyToManyField: RedisManyToMany
                 }
 
                 redis_field = RedisString
                 if django_field.__class__ in field_mapping.keys():
                     redis_field = field_mapping[django_field.__class__]
 
+                print(django_field.__class__.name)
                 redis_field = type(
                     django_field.__class__.name,
                     (redis_field,),
@@ -555,7 +554,7 @@ class RedisRoot:
                     else:
                         raise Exception(f'{name} -> cache config -> ttl must be int')
                 if 'django_model' in user_cache_conf.keys():
-                    if issubclass(user_cache_conf['django_model'], DjangoModel):
+                    if issubclass(user_cache_conf['django_model'], django_models.Model):
                         cache_conf['django_model'] = user_cache_conf['django_model']
                     else:
                         raise Exception(
@@ -578,7 +577,7 @@ class RedisRoot:
 
     def register_django_models(self, models_dict):
         for model, user_cache_conf in models_dict.items():
-            if issubclass(model, DjangoModel):
+            if issubclass(model, django_models.Model):
                 if model not in self.registered_django_models.keys():
                     cache_conf = self.get_cache_conf(model, user_cache_conf)
                     self.registered_django_models[model] = {
@@ -586,7 +585,7 @@ class RedisRoot:
                         'to_cache_in': datetime.datetime.now()
                     }
             else:
-                raise Exception(f'{model.__name__} class is not DjangoModel')
+                raise Exception(f'{model.__name__} class is not django_models.Model')
 
     def _get_registered_model_by_name(self, model_name):
         found = False
